@@ -14,11 +14,13 @@
 #' @param daten a data matrix, potentially with missing values, comprising dichotomous responses of respondents (rows) on some items (colums) coded in the 0 1 manner.
 #' @param sortdif logical, if TRUE (default) items are sorted in an ascending order by difficulty for output.
 #' @param pot logical, if TRUE (default) a power of three of the pairwise comparison matrix is used for further calculations.
+#' @param zerocor logical, if TRUE (default) unobserved combinations (1-0, 0-1) in data for each pair of items are given a frequency of one conf. proposal by Alexandrowicz(2011, p.373).
 #' @param ... additional parameters passed through
 #' @return An object of class ippw containing item difficulties sigma.
 #' @exportClass ippw
 #' @references Choppin, B. (1968). Item Bank using Samplefree Calibration. \emph{Nature, 219}(5156), 870-872.
 #' @references Choppin, B. (1985). A fully conditional estimation procedure for Rasch model parameters. \emph{Evaluation in Education, 9}(1), 29-42.
+#' @references Alexandrowicz, R. W. (2011). 'GANZ RASCH': A Free Software for Categorical Data Analysis. \emph{Social Science Computer Review, 30}(3), 369-379.
 #' 
 #' @examples data(cog) # loading example data set
 #' sigma<-itempar.dicho(daten=cog[,4:34], pot=TRUE) # calculating itemparameters for 31 math items
@@ -26,23 +28,21 @@
 #' #######
 #' plot(sigma) # plotting item difficulties
 ############## funktions beginn ########################################################
-itempar.dicho<-function(daten, sortdif=TRUE, pot=TRUE,...)
+itempar.dicho<-function(daten, sortdif=TRUE, pot=TRUE, zerocor=TRUE, ...)
 {
   ######### hier erste einzelne hilfsfunktionen 
   ### mat.mult - erweiterte matrix multiplikation mit NA's
   mat.mult<-function(A,B,na.rm=TRUE){
+    # new version based on remarks by A. Robitzsch
     A<-as.matrix(A);B<-as.matrix(B)
     if(dim(A)[2]!=dim(B)[1]){stop("not conformable Matrices A B")}
-    erg<-matrix( ,ncol=dim(A)[1] ,nrow=dim(B)[2] )
-    for (n in 1:dim(A)[1]){
-      for (m in 1:dim(B)[2]){
-        erg[n,m]<-sum(A[n,]*B[,m],na.rm=na.rm)
-      }
-    }
+    A[ is.na(A) ] <- 0
+    B[ is.na(B) ] <- 0
+    erg <- A %*% B
     return(erg)
   }
   
-  ### nij.dicho - erstellen einer nij häufigkeitsmatrix
+  ### nij.dicho - erstellen einer nij haeufigkeitsmatrix
   nij.dicho<-function(daten,...){
     Itemnames<-colnames(daten)
     nijmat<-t(mat.mult(A = t(!daten),B = daten )) 
@@ -52,21 +52,14 @@ itempar.dicho<-function(daten, sortdif=TRUE, pot=TRUE,...)
   }
   
   ### d3.mat - potenzieren von nij mit 3 und dann positiv reziproke matrix
-  d3.mat<-function(nij,pot=TRUE){
+  d3.mat<-function(nij, pot=TRUE, zerocor=TRUE){
+    # new version based on remarks by A. Robitzsch
     Itemnames<-dimnames(nij)
-    if(pot==T){nij<-nij%*%nij%*%nij}
-    n<-dim(nij)[2]                    # Groeße der quadratischen nij Matrix feststellen
-    mat<-matrix( , nrow=n, ncol=n)    # Ergebnis-Matrix Dmat vorbereiten
-    for(i in 1:n)
-    {
-      for(j in i:n)
-      {
-        mat[i,j] <- nij[j,i]/nij[i,j]
-        mat[j,i] <- nij[i,j]/nij[j,i]
-      }
-    }
-    Dmat <- mat
-    diag(Dmat) <- 1          # die NAs durch eins ersetzen
+    if(pot==TRUE){nij<-nij%*%nij%*%nij}
+    # new zero correction as an option --> conf. R. Alexandrowicz(2011) p.373 
+    if(zerocor==TRUE){nij[nij==0]<-1} 
+    Dmat <- t(nij) / nij
+    diag(Dmat)<-1
     dimnames(Dmat)<-Itemnames
     return (Dmat)
   }
@@ -96,7 +89,7 @@ itempar.dicho<-function(daten, sortdif=TRUE, pot=TRUE,...)
   }  
  
   ##### berechnung der ergebnisse ----------------
-  erg<-(sig.dicho(d3.mat(nij.dicho(as.matrix(daten)))))
+  erg<-(sig.dicho(d3.mat(nij.dicho(as.matrix(daten) ),pot=pot,zerocor=zerocor)))
   
   ##### aufbereitung der ergebnisse und ausgabe ----------------
   Itemnames<-colnames(daten)
@@ -105,7 +98,7 @@ itempar.dicho<-function(daten, sortdif=TRUE, pot=TRUE,...)
   if(sortdif==TRUE){Sigma<-sort(erg)}
   if(sortdif==FALSE){Sigma<-erg}
   
-  class(Sigma) <- c("ippw")
+  class(Sigma) <- c("numeric","ippw")
   return(Sigma)
   # summary.ippw(Sigma)
 }  
